@@ -1,6 +1,7 @@
 package jnr.posix;
 
 import jnr.constants.platform.Errno;
+import jnr.constants.platform.PosixFadvise;
 import jnr.constants.platform.Sysconf;
 import jnr.ffi.Memory;
 import jnr.ffi.Pointer;
@@ -8,6 +9,9 @@ import jnr.ffi.mapper.FromNativeContext;
 import jnr.posix.util.Platform;
 
 import java.io.FileDescriptor;
+import java.nio.ByteBuffer;
+import jnr.constants.platform.Confstr;
+import jnr.constants.platform.Pathconf;
 
 final class LinuxPOSIX extends BaseNativePOSIX implements Linux {
     private volatile boolean use_fxstat64 = true;
@@ -19,7 +23,7 @@ final class LinuxPOSIX extends BaseNativePOSIX implements Linux {
         super(libcProvider, handler);
 
 
-        if (Platform.IS_32_BIT || "sparcv9".equals(Platform.ARCH)) {
+        if (Platform.IS_32_BIT || "sparcv9".equals(Platform.ARCH) || Platform.ARCH.contains("mips64")) {
             statVersion = 3;
         } else {
             FileStat stat = allocateStat();
@@ -43,6 +47,9 @@ final class LinuxPOSIX extends BaseNativePOSIX implements Linux {
                 if ("sparcv9".equals(Platform.ARCH)) {
                     return new LinuxFileStatSPARCV9(this);
                 } else{
+		    if (Platform.ARCH.contains("mips64")) {
+		    	return new LinuxFileStatMIPS64(this);
+		    }
                     return new LinuxFileStat64(this);
                 }
             }
@@ -187,6 +194,14 @@ final class LinuxPOSIX extends BaseNativePOSIX implements Linux {
         return libc().sysconf(name);
     }
 
+    public int confstr(Confstr name, ByteBuffer buf, int len) {
+        return libc().confstr(name, buf, len);
+    }
+
+    public int fpathconf(int fd, Pathconf name) {
+        return libc().fpathconf(fd, name);
+    }
+
     public Times times() {
         return NativeTimes.times(this);
     }
@@ -202,6 +217,8 @@ final class LinuxPOSIX extends BaseNativePOSIX implements Linux {
         static final ABI _ABI_X86_64 = new ABI_X86_64();
         static final ABI _ABI_AARCH64 = new ABI_AARCH64();
         static final ABI _ABI_SPARCV9 = new ABI_SPARCV9();
+        static final ABI _ABI_PPC64 = new ABI_PPC64();
+        static final ABI _ABI_MIPS64 = new ABI_MIPS64();
 
         public static ABI abi() {
             if ("x86_64".equals(Platform.ARCH)) {
@@ -214,7 +231,11 @@ final class LinuxPOSIX extends BaseNativePOSIX implements Linux {
                 return _ABI_AARCH64;
             } else if ("sparcv9".equals(Platform.ARCH)) {
                 return _ABI_SPARCV9;
-            }
+            } else if (Platform.ARCH.contains("ppc64")) {
+                return _ABI_PPC64;
+            } else if (Platform.ARCH.contains("mips64")) {
+	    	return _ABI_MIPS64;
+	    }
             return null;
         }
 
@@ -270,6 +291,30 @@ final class LinuxPOSIX extends BaseNativePOSIX implements Linux {
                 return 218;
             }
         }
+
+        /** @see /usr/include/asm-generic/unistd.h */
+        final static class ABI_PPC64 implements ABI {
+            @Override
+            public int __NR_ioprio_set() {
+                return 273;
+            }
+            @Override
+            public int __NR_ioprio_get() {
+                return 274 ;
+            }
+        }
+
+        /** @see /usr/include/asm/unistd.h */
+        final static class ABI_MIPS64 implements ABI {
+            @Override
+            public int __NR_ioprio_set() {
+                return 5273;
+            }
+            @Override
+            public int __NR_ioprio_get() {
+                return 5274;
+            }
+        }
     }
 
     public int ioprio_get(int which, int who) {
@@ -291,4 +336,8 @@ final class LinuxPOSIX extends BaseNativePOSIX implements Linux {
 
         return libc().syscall(abi.__NR_ioprio_set(), which, who, ioprio);
     }
+
+    public int posix_fadvise(int fd, long offset, long len, PosixFadvise advise) {
+        return ((LinuxLibC) libc()).posix_fadvise(fd, offset, len, advise.intValue());
+    }
 }
