@@ -256,12 +256,13 @@ public class FileTest {
         assertArrayEquals(inContent, outContent);
     }
 
+    public static final int SEEK_SET = 0;
+
     @Test
     public void dup2Test() throws Throwable {
         File tmp = File.createTempFile("dupTest", "tmp");
-        RandomAccessFile raf = new RandomAccessFile(tmp, "rw");
-        int oldFd = getFdFromDescriptor(JavaLibCHelper.getDescriptorFromChannel(new RandomAccessFile(tmp, "rw").getChannel()));
-        int newFd = getFdFromDescriptor(JavaLibCHelper.getDescriptorFromChannel(raf.getChannel()));
+        int oldFd = posix.open(tmp.getAbsolutePath(), OpenFlags.O_RDWR.intValue(), 0666);
+        int newFd = 1000;
 
         byte[] outContent = "foo".getBytes();
 
@@ -272,7 +273,7 @@ public class FileTest {
         FileDescriptor newFileDescriptor = toDescriptor(newFd);
 
         new FileOutputStream(toDescriptor(oldFd)).write(outContent);
-        raf.seek(0);
+        posix.lseek(newFd, SEEK_SET, 0);
 
         byte[] inContent = new byte[outContent.length];
         new FileInputStream(newFileDescriptor).read(inContent, 0, 3);
@@ -284,15 +285,16 @@ public class FileTest {
     public void fcntlDupfdTest() throws Throwable {
         if (!Platform.IS_WINDOWS) {
             File tmp = File.createTempFile("fcntlTest", "tmp");
-            RandomAccessFile raf = new RandomAccessFile(tmp, "rw");
-            int fd = JavaLibCHelper.getfdFromDescriptor(JavaLibCHelper.getDescriptorFromChannel(raf.getChannel()));
+            int fd = posix.open(tmp.getPath(), OpenFlags.O_RDWR.intValue(), 0444);
 
             byte[] outContent = "foo".getBytes();
 
-            int newFd = posix.fcntl(fd, Fcntl.F_DUPFD);
+            // NOTE: This test used to call without the third argument, but this leads to undefined behavior.
+            // See https://github.com/jnr/jnr-posix/issues/144
+            int newFd = posix.fcntl(fd, Fcntl.F_DUPFD, 0);
 
             new FileOutputStream(JavaLibCHelper.toFileDescriptor(fd)).write(outContent);
-            raf.seek(0);
+            posix.lseek(fd, SEEK_SET, 0);
 
             byte[] inContent = new byte[outContent.length];
             new FileInputStream(JavaLibCHelper.toFileDescriptor(newFd)).read(inContent, 0, 3);
@@ -312,14 +314,15 @@ public class FileTest {
 
             byte[] outContent = "foo".getBytes();
 
-            int dupFd = posix.fcntl(oldFd, Fcntl.F_DUPFD, newFd);
+            int expectedFd = 100;
+            int dupFd = posix.fcntl(oldFd, Fcntl.F_DUPFD, expectedFd);
 
             new FileOutputStream(JavaLibCHelper.toFileDescriptor(newFd)).write(outContent);
 
             byte[] inContent = new byte[outContent.length];
             new FileInputStream(JavaLibCHelper.toFileDescriptor(dupFd)).read(inContent, 0, 3);
 
-            assertTrue(dupFd > newFd);
+            assertTrue(dupFd >= expectedFd);
             assertArrayEquals(inContent, outContent);
         }
     }
@@ -501,17 +504,18 @@ public class FileTest {
         jnr.constants.platform.Access.F_OK.intValue();
 
         // Set permissions to read-only and verify we don't have permissions to write.
-        posix.chmod(tmp.getCanonicalPath(), 0400);
-        assertEquals("access: ", -1, posix.access(tmp.getCanonicalPath(), Access.W_OK.intValue()));
-        assertEquals("access: ", 0, posix.access(tmp.getCanonicalPath(), Access.R_OK.intValue()));
+        String canonicalPath = tmp.getCanonicalPath();
+        assertEquals("chmod 0400: ", 0, posix.chmod(canonicalPath, 0400));
+        assertEquals("access " + canonicalPath + " for write: ", -1, posix.access(canonicalPath, Access.W_OK.intValue()));
+        assertEquals("access " + canonicalPath + " for read: ", 0, posix.access(canonicalPath, Access.R_OK.intValue()));
 
-        // Reset the permissions to read-wrinte and verify we now have permissions to write.
-        posix.chmod(tmp.getCanonicalPath(), 0600);
-        assertEquals("access: ", 0, posix.access(tmp.getCanonicalPath(), Access.W_OK.intValue()));
-        assertEquals("access: ", 0, posix.access(tmp.getCanonicalPath(), Access.R_OK.intValue()));
+        // Reset the permissions to read-write and verify we now have permissions to write.
+        assertEquals("chmod 0600: ", 0, posix.chmod(canonicalPath, 0600));
+        assertEquals("access " + canonicalPath + " for write: ", 0, posix.access(canonicalPath, Access.W_OK.intValue()));
+        assertEquals("access " + canonicalPath + " for read: ", 0, posix.access(canonicalPath, Access.R_OK.intValue()));
 
         // F_OK just checks the file exists and should pass.
-        assertEquals("access: ", 0, posix.access(tmp.getCanonicalPath(), Access.F_OK.intValue()));
+        assertEquals("access " + canonicalPath + " exists: ", 0, posix.access(canonicalPath, Access.F_OK.intValue()));
     }
 
     @Test
